@@ -6,6 +6,7 @@ from collections import defaultdict, namedtuple
 from csv import DictReader
 from datetime import datetime
 from decimal import Decimal
+from distutils.dir_util import copy_tree
 from flask import request
 from flask.views import View as _View
 from itertools import islice
@@ -13,6 +14,8 @@ from json import dumps, loads
 from functools import partial, wraps
 from logging import getLogger
 from math import ceil
+from os import mkdir
+from os.path import dirname, exists, join
 from re import sub
 from sqlalchemy.ext.mutable import Mutable
 from sqlalchemy.orm import Query
@@ -86,6 +89,8 @@ def convert(value, rtype=None, allow_json=False):
           return True
         elif value.lower() == 'false':
           return False
+        elif value == 'None':
+          return None
         else:
           if allow_json:
             try:
@@ -215,8 +220,8 @@ class Dict(dict):
     
     """
     values = [
-        cls(dct)
-        for value in self.itervalues()
+        cls(value)
+        for value in dct.itervalues()
         if isinstance(value, dict)
     ]
     return sum(cls.width(value) for value in values) + len(dct) - len(values)
@@ -233,6 +238,10 @@ class Dict(dict):
     :type prefix: str
     :rtype: dict:
 
+    .. note::
+
+      All keys in the dictionary must be strings.
+
     """
     items = []
     for key, value in dct.iteritems():
@@ -440,21 +449,22 @@ class Cacheable(object):
 
     """
     cached_properties = set(self._get_cached_properties())
+
     if names:
       for name in names:
         if name in cached_properties:
           setattr(self, name, _CacheRefresh(expiration))
         else:
           raise AttributeError('No cached property %r on %r.' % (name, self))
-      if remove_deleted:
-        for varname in self._cache.keys():
-          if not varname in cached_properties:
-            del self._cache[varname]
     else:
-      if remove_deleted:
-        self._cache = {}
       for varname in cached_properties:
         setattr(self, varname, _CacheRefresh(expiration))
+
+    if remove_deleted:
+      for varname in self._cache:
+        if not varname in cached_properties:
+          del self._cache[varname]
+
     try:
       self._cache.changed()
     except:
@@ -979,6 +989,17 @@ def make_view(app, view_class=View, view_name='View', **kwargs):
   kwargs.update({'__app__': app})
   return type(view_name, (view_class, ), kwargs)
 
+
+def generate_app(foldername='app'):
+  """Create bootstrap app."""
+  src = dirname(__file__)
+  if exists(foldername):
+    print 'That folder already seems to exist. App creation skipped.'
+  else:
+    mkdir(foldername)
+    copy_tree(join(src, 'data', 'app'), foldername)
+    print 'Bootstrap app folder created in %s!' % (foldername, )
+
 # ===
 #
 # Computations
